@@ -30,7 +30,8 @@ class QtSassThemeGetter:
                     f.write(import_abspath_str + '\n' + fdata)
 
     def setThemeColor(self, bg_color, widget_color, text_color, hover_color, border_color,
-                       select_color, disabled_color, text_widget_color, scroll_handle_color):
+                       select_color, disabled_color, text_widget_color, scroll_handle_color,
+                      splitter_handle_color):
         variables = f'''$bgcolor: {bg_color};
         $widgetcolor: {widget_color};
         $textcolor: {text_color};
@@ -40,6 +41,7 @@ class QtSassThemeGetter:
         $disabledcolor: {disabled_color};
         $textwidgetcolor: {text_widget_color};
         $scrollhandlecolor: {scroll_handle_color};
+        $splitterhandlecolor: {splitter_handle_color};
 '''
         cur_dir = os.path.dirname(__file__)
         var_filename = os.path.join(cur_dir, 'var/variables.scss')
